@@ -134,7 +134,7 @@ class OsDetector(object):
 
 class LsbDetect(OsDetector):
     """
-    Generic detector for Debian, Ubuntu, and Mint
+    Generic detector for Debian, Ubuntu, Mint, and Pop! OS
     """
     def __init__(self, lsb_name, get_version_fn=None):
         self.lsb_name = lsb_name
@@ -729,7 +729,9 @@ OS_OPENEMBEDDED = 'openembedded'
 OS_OPENSUSE = 'opensuse'
 OS_OPENSUSE13 = 'opensuse'
 OS_TIZEN = 'tizen'
+OS_SAILFISHOS = 'sailfishos'
 OS_OSX = 'osx'
+OS_POP = 'pop'
 OS_QNX = 'qnx'
 OS_RHEL = 'rhel'
 OS_SLACKWARE = 'slackware'
@@ -761,7 +763,9 @@ OsDetect.register_default(OS_OPENSUSE13, OpenSuse(brand_file='/etc/SUSE-brand',
 OsDetect.register_default(OS_OPENSUSE, FdoDetect("opensuse-tumbleweed"))
 OsDetect.register_default(OS_OPENSUSE, FdoDetect("opensuse"))
 OsDetect.register_default(OS_TIZEN, FdoDetect("tizen"))
+OsDetect.register_default(OS_SAILFISHOS, FdoDetect("sailfishos"))
 OsDetect.register_default(OS_OSX, OSX())
+OsDetect.register_default(OS_POP, LsbDetect("Pop"))
 OsDetect.register_default(OS_QNX, QNX())
 OsDetect.register_default(OS_RHEL, Rhel())
 OsDetect.register_default(OS_SLACKWARE, Slackware())
